@@ -13,7 +13,7 @@ def default(params, files):
     return {"response": "hello world"}, {}
 
 
-if __name__ == "__main__":
+def main():
     parser = argparse.ArgumentParser(description="Example RPCServer for RabbitMQ")
     parser.add_argument("--host", default="localhost", type=str, help="host")
     parser.add_argument("--port", default=5672, type=int, help="port")
@@ -24,3 +24,7 @@ if __name__ == "__main__":
     app = RpcServer(host=args.host, port=args.port, username=args.username, password=args.password,
                     procedures={"addition": addition, "default": default})
 
+
+if __name__ == "__main__":
+    main()
+
